lib

package
v0.0.0-...-cf7471f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2016 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Uploader

type Uploader struct {
	Acipath  string
	Ascpath  string
	Uri      string
	Insecure bool
	Debug    bool

	// SetHTTPHeaders is called on every request before being sent.
	// This is exposed so that the user of acpush can set any headers
	// necessary for authentication.
	SetHTTPHeaders func(*http.Request)
}

Uploader holds information about an upload to be performed.

func (Uploader) Upload

func (u Uploader) Upload() error

Upload performs the upload of the ACI and signature specified in the Uploader struct.

Jump to