Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Uploader ¶
type Uploader struct {
Acipath string
Ascpath string
Uri string
Insecure bool
Debug bool
// SetHTTPHeaders is called on every request before being sent.
// This is exposed so that the user of acpush can set any headers
// necessary for authentication.
SetHTTPHeaders func(*http.Request)
}
Uploader holds information about an upload to be performed.
Click to show internal directories.
Click to hide internal directories.